"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const Issuer_json_1 = __importDefault(require("../../build/contracts/Issuer.json"));
class Issuer extends utils_general_1.GeneralFunctions {
    constructor(web3, address) {
        const buildFile = Issuer_json_1.default;
        const buildFileAbi = buildFile.abi;
        super(address
            ? new web3.eth.Contract(buildFileAbi, address)
            : new web3.eth.Contract(buildFileAbi, buildFile.networks.length > 0 ? buildFile.networks[0] : null));
        this.web3 = web3;
    }
    async initialize(certificateTopic, registryAddress, owner, txParams) {
        const method = this.web3Contract.methods.initialize(certificateTopic, registryAddress, owner);
        return this.send(method, txParams);
    }
    async getAllEvents(eventFilter) {
        return this.web3Contract.getPastEvents('allEvents', this.createFilter(eventFilter));
    }
    async getAllNewCertificationRequestEvents(eventFilter) {
        return this.web3Contract.getPastEvents('NewCertificationRequest', this.createFilter(eventFilter));
    }
    async encodeData(_from, _to, _deviceId, txParams) {
        return this.web3Contract.methods.encodeData(_from, _to, _deviceId).call(txParams);
    }
    async decodeData(_data, txParams) {
        return this.web3Contract.methods.decodeData(_data).call(txParams);
    }
    async getCertificationRequest(_certificationRequestId, txParams) {
        return this.web3Contract.methods
            .getCertificationRequest(_certificationRequestId)
            .call(txParams);
    }
    async getCertificationRequestsForDevice(_deviceId, txParams) {
        const ids = await this.web3Contract.methods
            .getCertificationRequestsForDevice(_deviceId)
            .call(txParams);
        return ids.map((id) => Number(id));
    }
    async getCertificateCommitment(_certificateId, txParams) {
        return this.web3Contract.methods.getCertificateCommitment(_certificateId).call(txParams);
    }
    async requestCertification(_data, _isPrivate, txParams) {
        const method = this.web3Contract.methods.requestCertification(_data, _isPrivate);
        return this.send(method, txParams);
    }
    async requestCertificationFor(_data, _forAddress, _isPrivate, txParams) {
        const method = this.web3Contract.methods.requestCertificationFor(_data, _forAddress, _isPrivate);
        return this.send(method, txParams);
    }
    async approveCertificationRequest(_requestId, _value, _validityData, txParams) {
        const method = this.web3Contract.methods.approveCertificationRequest(_requestId, _value, _validityData);
        return this.send(method, txParams);
    }
    async issue(_to, _value, _data, txParams) {
        const method = this.web3Contract.methods.issue(_to, _value, _data);
        return this.send(method, txParams);
    }
    async approveCertificationRequestPrivate(_requestId, _commitment, _validityData, txParams) {
        const method = this.web3Contract.methods.approveCertificationRequestPrivate(_requestId, _commitment, _validityData);
        return this.send(method, txParams);
    }
    async issuePrivate(_to, _commitment, _data, txParams) {
        const method = this.web3Contract.methods.issuePrivate(_to, _commitment, _data);
        return this.send(method, txParams);
    }
    async revokeRequest(_requestId, txParams) {
        const method = this.web3Contract.methods.revokeRequest(_requestId);
        return this.send(method, txParams);
    }
    async revokeCertificate(_certificateId, txParams) {
        const method = this.web3Contract.methods.revokeCertificate(_certificateId);
        return this.send(method, txParams);
    }
    async updateCommitment(_id, _previousCommitment, _commitment, txParams) {
        const method = this.web3Contract.methods.updateCommitment(_id, _previousCommitment, _commitment);
        return this.send(method, txParams);
    }
    async requestMigrateToPublic(_certificateId, _hash, txParams) {
        const method = this.web3Contract.methods.requestMigrateToPublic(_certificateId, _hash);
        return this.send(method, txParams);
    }
    async getPrivateTransferRequest(_certificateId, txParams) {
        return this.web3Contract.methods.getPrivateTransferRequest(_certificateId).call(txParams);
    }
    async getMigrationRequestId(_certificateId, txParams) {
        return this.web3Contract.methods.getMigrationRequestId(_certificateId).call(txParams);
    }
    async getMigrationRequest(_requestId, txParams) {
        return this.web3Contract.methods.getMigrationRequest(_requestId).call(txParams);
    }
    async migrateToPublic(_requestId, _value, _salt, _proof, txParams) {
        const method = this.web3Contract.methods.migrateToPublic(_requestId, _value, _salt, _proof);
        return this.send(method, txParams);
    }
    async approvePrivateTransfer(_certificateId, _proof, _previousCommitment, _commitment, txParams) {
        const method = this.web3Contract.methods.approvePrivateTransfer(_certificateId, _proof, _previousCommitment, _commitment);
        return this.send(method, txParams);
    }
    async requestPrivateTransfer(_certificateId, _hash, txParams) {
        const method = this.web3Contract.methods.requestPrivateTransfer(_certificateId, _hash);
        return this.send(method, txParams);
    }
    async getCertificationRequestForCertificate(_certificateId, txParams) {
        return this.web3Contract.methods
            .getCertificationRequestForCertificate(_certificateId)
            .call(txParams);
    }
    async getCertificationRequestIdForCertificate(_certificateId, txParams) {
        const id = await this.web3Contract.methods
            .getCertificationRequestIdForCertificate(_certificateId)
            .call(txParams);
        return Number(id);
    }
    async getCertificateIdForCertificationRequest(_requestId, txParams) {
        const id = await this.web3Contract.methods
            .getCertificateIdForCertificationRequest(_requestId)
            .call(txParams);
        return Number(id);
    }
    async getRegistryAddress(txParams) {
        return this.web3Contract.methods.getRegistryAddress().call(txParams);
    }
    async totalRequests(txParams) {
        return this.web3Contract.methods.totalRequests().call(txParams);
    }
    async version(txParams) {
        return this.web3Contract.methods.version().call(txParams);
    }
}
exports.Issuer = Issuer;
//# sourceMappingURL=Issuer.js.map